Header menu logo PhysicsSandbox

ShapeBuilders Module

Functions and values

Function or value Description

mkBox halfX halfY halfZ

Full Usage: mkBox halfX halfY halfZ

Parameters:
    halfX : float
    halfY : float
    halfZ : float

Returns: Shape

Create a Box shape with the given half-extents.

halfX : float
halfY : float
halfZ : float
Returns: Shape

mkCapsule radius length

Full Usage: mkCapsule radius length

Parameters:
    radius : float
    length : float

Returns: Shape

Create a Capsule shape with the given radius and length.

radius : float
length : float
Returns: Shape

mkCylinder radius length

Full Usage: mkCylinder radius length

Parameters:
    radius : float
    length : float

Returns: Shape

Create a Cylinder shape with the given radius and length.

radius : float
length : float
Returns: Shape

mkPlane normal

Full Usage: mkPlane normal

Parameters:
    normal : float * float * float

Returns: Shape

Create a Plane shape with the given normal direction.

normal : float * float * float
Returns: Shape

mkSphere radius

Full Usage: mkSphere radius

Parameters:
    radius : float

Returns: Shape

Create a Sphere shape with the given radius.

radius : float
Returns: Shape

mkTriangle a b c

Full Usage: mkTriangle a b c

Parameters:
    a : float * float * float
    b : float * float * float
    c : float * float * float

Returns: Shape

Create a Triangle shape with three vertex positions.

a : float * float * float
b : float * float * float
c : float * float * float
Returns: Shape

Type something to start searching.