ShapeBuilders Module
Functions and values
| Function or value |
Description
|
Full Usage:
mkBox halfX halfY halfZ
Parameters:
float
halfY : float
halfZ : float
Returns: Shape
|
Create a Box shape with the given half-extents.
|
|
Create a Capsule shape with the given radius and length.
|
|
Create a Cylinder shape with the given radius and length.
|
|
|
|
|
Full Usage:
mkTriangle a b c
Parameters:
float * float * float
b : float * float * float
c : float * float * float
Returns: Shape
|
Create a Triangle shape with three vertex positions.
|
PhysicsSandbox